@@ -7,17 +7,17 @@ from web3.types import ChecksumAddress
 address_mumbai: Dict[str, ChecksumAddress] = {
     k: Web3.toChecksumAddress(v)
     for k, v in {
-        "StableToken": "0x27f43eF37bc44120eDD91626f40C6DFa8908300C",
-        "Manager": "0x25074928fA2cDd06Fb9f0902d710f7EDB494dbe2",
-        "Amm_eth-usdc": "0x9e7225628bB6f9F437F123287602f59d705c8AA1",
-        "Amm_btc-usdc": "0x40Ff56e22D26B41F13f79D61311e7DA605C0c4c2",
-        "Amm_matic-usdc": "0xaB0BcF1F2f24145EcB2EAF3A11B8E1A25A839de7",
-        "AmmReader": "0x410325f7A08FD56374a822db318E2593c9e5F5C8"
+        "StableToken": "0x2E4c42aB89E8f928C74571Bb54C2DaA28605937B",
+        "Manager": "0xc7Bf6E9a1EE40EB452712F219Ffd57D0feE0691c",
+        "Amm_eth-usdc": "0x9fFeBA1A8cD88D0BDb996Cf75A993fdAfEE8f4f6",
+        "Amm_btc-usdc": "0xec8c5521c4Df81be57436a5DC9e2Ac4C888E0054",
+        "Amm_matic-usdc": "0x74456feE1Cf361787EA0545B7f075A72084a3965",
+        "AmmReader": "0x314426488153C2867Dbb1FC1dee3B406F9E3c7B0"
     }.items()
 }
-}
 
-address_mumbai: Dict[str, ChecksumAddress] = {
+
+address_matic: Dict[str, ChecksumAddress] = {
     k: Web3.toChecksumAddress(v)
     for k, v in {
         "StableToken": "0x2791bca1f2de4661ed88a30c99a7a9449aa84174",            
@@ -29,5 +29,4 @@ address_mumbai: Dict[str, ChecksumAddress] = {
         "Amm_dot-usdc": "0x6F88D5D707908e961228C4708D19a6252B546e13",
         "AmmReader": "0x3e33b0FefD9C1886bd07C3308212f0f4a7c4A38d"
     }.items()
-}
 }
\ No newline at end of file
