@@ -42,6 +42,7 @@ class StatusCode(Enum):
     RETRY_FAILED = 3015
     TRANSACTION_EXISTS = 3016
     TRANSACTION_NOT_CANCELLED = 3017
+    CANNOT_FETCH_GAS_FEES = 3018
 
     
 @unique
@@ -100,6 +101,8 @@ class ErrorMessage(Enum):
     TRANSACTION_RETRY_ERROR = 'Failed to retry the transaction. Please try again.'
     TRANSACTION_EXISTS = 'Cannot retry/cancel. Transaction is already completed.'
 
+    CANNOT_FETCH_GAS_FEES = 'Unable to fetch gas fee'
+
 @unique
 class PnlCalcOption(Enum):
     SPOT_PRICE = 0
